aboutsummaryrefslogtreecommitdiffstats
path: root/src/gwin/class_gwin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gwin/class_gwin.h')
-rw-r--r--src/gwin/class_gwin.h16
1 files changed, 15 insertions, 1 deletions
diff --git a/src/gwin/class_gwin.h b/src/gwin/class_gwin.h
index c4442264..488f3d68 100644
--- a/src/gwin/class_gwin.h
+++ b/src/gwin/class_gwin.h
@@ -211,7 +211,7 @@ typedef enum GRedrawMethod { REDRAW_WAIT, REDRAW_NOWAIT, REDRAW_INSESSION } GRed
/**
* @brief Flush any pending redraws in the system.
*
* @param[in] doWait Do we wait for the lock?
*
* @note This call will attempt to flush any pending redraws
* in the system. The doWait parameter tells this call
@@ -243,6 +243,20 @@ bool_t _gwinDrawStart(GHandle gh);
void _gwinDrawEnd(GHandle gh);
/**
+ * @brief Flush any pending redraws in the system.
+ *
+ * @param[in] gh The window
+ * @param[in] how Do we wait for the lock?
+ *
+ * @note This call will delete the window. If called without the
+ * drawing lock 'how' must be REDRAW_WAIT. If called with the drawing
+ * lock 'how' must be REDRAW_INSESSION.
+ *
+ * @notapi
+ */
+void _gwinDestroy(GHandle gh, GRedrawMethod how);
+
+/**
* @brief Add a window to the window manager and set its position and size
* @return TRUE if successful
*
@@ -211,7 +211,7 @@ typedef enum GRedrawMethod { REDRAW_WAIT, REDRAW_NOWAIT, REDRAW_INSESSION } GRed
* @brief Flush any pending redraws in the system.
*
- * @param[in] doWait Do we wait for the lock?
+ * @param[in] how Do we wait for the lock?
*
* @note This call will attempt to flush any pending redraws